Module IParserV2

Module IParserV2 

Generated by the following Solidity interface…

interface IParserV2 {
    function parse2(bytes memory data) external view returns (bytes memory bytecode);
}

…which was generated by the following JSON ABI:

[
  {
    "type": "function",
    "name": "parse2",
    "inputs": [
      {
        "name": "data",
        "type": "bytes",
        "internalType": "bytes"
      }
    ],
    "outputs": [
      {
        "name": "bytecode",
        "type": "bytes",
        "internalType": "bytes"
      }
    ],
    "stateMutability": "view"
  }
]

Structs

parse2Call
Function with signature parse2(bytes) and selector 0xa3869e14.
parse2Return
Container type for the return parameters of the parse2(bytes) function.

Enums

IParserV2Calls
Container for all the IParserV2 function calls.

Statics

BYTECODE
The creation / init bytecode of the contract.
DEPLOYED_BYTECODE
The runtime bytecode of the contract, as deployed on the network.